summaryrefslogtreecommitdiffstats
path: root/noatun/library/noatun/stdaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/noatun/stdaction.h')
-rw-r--r--noatun/library/noatun/stdaction.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/noatun/library/noatun/stdaction.h b/noatun/library/noatun/stdaction.h
index 9f9b639e..2a5ad401 100644
--- a/noatun/library/noatun/stdaction.h
+++ b/noatun/library/noatun/stdaction.h
@@ -4,7 +4,7 @@
#include <kaction.h>
#include <kactionclasses.h>
#include <kdemacros.h>
-class KPopupMenu;
+class TDEPopupMenu;
/**
* Holds all noatun related actions
@@ -17,7 +17,7 @@ namespace NoatunStdAction
/**
* An action starting noatun playback
**/
-class PlayAction : public KAction
+class PlayAction : public TDEAction
{
Q_OBJECT
@@ -31,7 +31,7 @@ private slots:
/**
* An action starting/stopping noatun playback
**/
-class PlaylistAction : public KToggleAction
+class PlaylistAction : public TDEToggleAction
{
Q_OBJECT
@@ -46,7 +46,7 @@ private slots:
* actionmenu that holds all plugin defined actions
* @author Stefan Gehn
*/
-class PluginActionMenu : public KActionMenu
+class PluginActionMenu : public TDEActionMenu
{
Q_OBJECT
@@ -57,11 +57,11 @@ public:
* @param action the action to insert
* @param index defines the place where the action gets displayed in
*/
- virtual void insert (KAction *action, int index=-1);
+ virtual void insert (TDEAction *action, int index=-1);
/**
* removes the given @p action into the action-menu
*/
- virtual void remove(KAction *action);
+ virtual void remove(TDEAction *action);
/**
* Wrapper method for old Noatun API
* <b>DON'T USE</b>
@@ -80,7 +80,7 @@ private:
* actionmenu that holds all vis-plugins for easier enabling/disabling
* @author Stefan Gehn
*/
-class VisActionMenu : public KActionMenu
+class VisActionMenu : public TDEActionMenu
{
Q_OBJECT
@@ -98,7 +98,7 @@ private:
* actionmenu that holds all looping modes
* @author Stefan Gehn
*/
-class LoopActionMenu : public KActionMenu
+class LoopActionMenu : public TDEActionMenu
{
Q_OBJECT
@@ -111,43 +111,43 @@ private slots:
void loopPlaylistSelected();
void loopRandomSelected();
private:
- KRadioAction *mLoopNone;
- KRadioAction *mLoopSong;
- KRadioAction *mLoopPlaylist;
- KRadioAction *mLoopRandom;
+ TDERadioAction *mLoopNone;
+ TDERadioAction *mLoopSong;
+ TDERadioAction *mLoopPlaylist;
+ TDERadioAction *mLoopRandom;
};
/**
* @return pointer to a KAction which opens the effects dialog on activation
*/
-KDE_EXPORT KAction *effects(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *effects(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KAction which opens the equalizer dialog on activation
*/
-KDE_EXPORT KAction *equalizer(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *equalizer(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KAction which goes back one track on activation
*/
-KDE_EXPORT KAction *back(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *back(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KAction which stops playback on activation
*/
-KDE_EXPORT KAction *stop(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *stop(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KAction which starts/pauses playback on activation
*/
-KDE_EXPORT KAction *playpause(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *playpause(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KAction which advances one track on activation
*/
-KDE_EXPORT KAction *forward(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *forward(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to a KToggleAction which shows/hides the playlist
*/
-KDE_EXPORT KToggleAction *playlist(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEToggleAction *playlist(TQObject *parent = 0, const char *name = 0);
/**
* loop action
@@ -157,12 +157,12 @@ KDE_EXPORT LoopActionMenu *loop(TQObject *parent, const char *name);
/**
* play action
*/
-KDE_EXPORT KAction *play(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *play(TQObject *parent = 0, const char *name = 0);
/**
* pause action
*/
-KDE_EXPORT KAction *pause(TQObject *parent = 0, const char *name = 0);
+KDE_EXPORT TDEAction *pause(TQObject *parent = 0, const char *name = 0);
/**
* @return pointer to the global PluginActionMenu object (there is only one instance)
@@ -181,7 +181,7 @@ KDE_EXPORT VisActionMenu *visualizations(TQObject *parent = 0, const char *name
class KDE_EXPORT ContextMenu
{
public:
- static KPopupMenu *createContextMenu(TQWidget *p);
+ static TDEPopupMenu *createContextMenu(TQWidget *p);
/**
* One menu to show them all, One menu to find them
@@ -189,7 +189,7 @@ public:
*
* In the land of Noatun where the oceans die
*/
- static KPopupMenu *contextMenu();
+ static TDEPopupMenu *contextMenu();
/**
* Show the context menu at point
@@ -201,7 +201,7 @@ public:
**/
static void showContextMenu();
private:
- static KPopupMenu *mContextMenu;
+ static TDEPopupMenu *mContextMenu;
};
}
@@ -111,43 +111,43 @@ private slots:
};
/**
- * @return pointer to a KAction which opens the effects dialog on activation
+ * @return pointer to a TDEAction which opens the effects dialog on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KAction which opens the equalizer dialog on activation
+ * @return pointer to a TDEAction which opens the equalizer dialog on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KAction which goes back one track on activation
+ * @return pointer to a TDEAction which goes back one track on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KAction which stops playback on activation
+ * @return pointer to a TDEAction which stops playback on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KAction which starts/pauses playback on activation
+ * @return pointer to a TDEAction which starts/pauses playback on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KAction which advances one track on activation
+ * @return pointer to a TDEAction which advances one track on activation
*/
@@ -111,43 +111,43 @@ private slots:
/**
- * @return pointer to a KToggleAction which shows/hides the playlist
+ * @return pointer to a TDEToggleAction which shows/hides the playlist
*/